@@ -7,7 +7,7 @@ import os
 import datasets
 
 
-_URL_ = "https://storage.googleapis.com/discofuse.appspot.com/"
+_URL_ = "https://storage.googleapis.com/gresearch/discofuse/"
 _CITATION = """\
 @InProceedings{GevaEtAl2019,
   title = {DiscoFuse: A Large-Scale Dataset for Discourse-Based Sentence Fusion},
