@@ -20,6 +20,7 @@
 import os
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 _DESCRIPTION = """\
@@ -94,6 +95,7 @@ class Metrec(datasets.GeneratorBasedBuilder):
             supervised_keys=None,
             homepage="https://github.com/zaidalyafeai/MetRec",
             citation=_CITATION,
+            task_templates=[TextClassification(text_column="text", label_column="label")],
         )
 
     def _vocab_text_gen(self, archive):
