@@ -18,6 +18,7 @@ import csv
 import os
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 # no BibTeX citation
@@ -53,6 +54,7 @@ class MyanmarNews(datasets.GeneratorBasedBuilder):
             homepage="https://github.com/ayehninnkhine/MyanmarNewsClassificationSystem",
             license=_LICENSE,
             citation=_CITATION,
+            task_templates=[TextClassification(text_column="text", label_column="category")],
         )
 
     def _split_generators(self, dl_manager):
