@@ -19,6 +19,7 @@ import csv
 import os
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 _CITATION = """\
@@ -68,6 +69,7 @@ class NkjpNer(datasets.GeneratorBasedBuilder):
             homepage=_HOMEPAGE,
             license=_LICENSE,
             citation=_CITATION,
+            task_templates=[TextClassification(text_column="sentence", label_column="target")],
         )
 
     def _split_generators(self, dl_manager):
