@@ -18,6 +18,7 @@
 import os
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 logger = datasets.logging.get_logger(__name__)
@@ -63,6 +64,7 @@ class OnestopEnglish(datasets.GeneratorBasedBuilder):
             homepage=_HOMEPAGE,
             license=_LICENSE,
             citation=_CITATION,
+            task_templates=[TextClassification(text_column="text", label_column="label")],
         )
 
     def _vocab_text_gen(self, train_file):
@@ -128,7 +130,6 @@ class OnestopEnglish(datasets.GeneratorBasedBuilder):
     def _generate_examples(self, split_key, data_dir):
         """Yields examples for a given split of dataset."""
         split_text, split_labels = self._get_examples_from_split(split_key, data_dir)
-        for text, label in zip(split_text, split_labels):
-            data_key = split_key + "_" + text
+        for id_, (text, label) in enumerate(zip(split_text, split_labels)):
             feature_dict = {"text": text, "label": label}
-            yield data_key, feature_dict
+            yield id_, feature_dict
