@@ -12,29 +12,57 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""CVIT IIIT-H PIB Multilingual Corpus"""
-
-
-import os
+"""CVIT PIB Multilingual Corpus"""
 
 import datasets
 
 
 _CITATION = """\
-@InProceedings{cvit-pib:multilingual-corpus,
-title = {Revisiting Low Resource Status of Indian Languages in Machine Translation},
-authors={Jerin Philip, Shashank Siripragada, Vinay P. Namboodiri, C.V. Jawahar
-},
-year={2020}
+@inproceedings{siripragada-etal-2020-multilingual,
+    title = "A Multilingual Parallel Corpora Collection Effort for {I}ndian Languages",
+    author = "Siripragada, Shashank  and
+      Philip, Jerin  and
+      Namboodiri, Vinay P.  and
+      Jawahar, C V",
+    booktitle = "Proceedings of the 12th Language Resources and Evaluation Conference",
+    month = may,
+    year = "2020",
+    address = "Marseille, France",
+    publisher = "European Language Resources Association",
+    url = "https://aclanthology.org/2020.lrec-1.462",
+    pages = "3743--3751",
+    language = "English",
+    ISBN = "979-10-95546-34-4",
+}
+@article{2020,
+   title={Revisiting Low Resource Status of Indian Languages in Machine Translation},
+   url={http://dx.doi.org/10.1145/3430984.3431026},
+   DOI={10.1145/3430984.3431026},
+   journal={8th ACM IKDD CODS and 26th COMAD},
+   publisher={ACM},
+   author={Philip, Jerin and Siripragada, Shashank and Namboodiri, Vinay P. and Jawahar, C. V.},
+   year={2020},
+   month={Dec}
 }
 """
 
 _DESCRIPTION = """\
-This new dataset is the large scale sentence aligned corpus in 11 Indian languages,
-viz. CVIT-PIB corpus that is the largest multilingual corpus available for Indian languages.
+Sentence aligned parallel corpus between 11 Indian Languages, crawled and extracted from the press information bureau
+website.
 """
 
-_URL = "http://preon.iiit.ac.in/~jerin/resources/datasets/pib-v0.tar"
+_HOMEPAGE = "http://preon.iiit.ac.in/~jerin/bhasha/"
+
+_LICENSE = "Creative Commons Attribution-ShareAlike 4.0 International"
+
+_URL = {
+    "0.0.0": "http://preon.iiit.ac.in/~jerin/resources/datasets/pib-v0.tar",
+    "1.3.0": "http://preon.iiit.ac.in/~jerin/resources/datasets/pib_v1.3.tar.gz",
+}
+_ROOT_DIR = {
+    "0.0.0": "pib",
+    "1.3.0": "pib-v1.3",
+}
 
 _LanguagePairs = [
     "or-ur",
@@ -98,8 +126,8 @@ _LanguagePairs = [
 class PibConfig(datasets.BuilderConfig):
     """BuilderConfig for PIB"""
 
-    def __init__(self, language_pair, **kwargs):
-        super().__init__(**kwargs)
+    def __init__(self, language_pair, version=datasets.Version("1.3.0"), **kwargs):
+        super().__init__(version=version, **kwargs)
         """
 
         Args:
@@ -118,36 +146,39 @@ class Pib(datasets.GeneratorBasedBuilder):
     BUILDER_CONFIGS = [PibConfig(name=pair, description=_DESCRIPTION, language_pair=pair) for pair in _LanguagePairs]
 
     def _info(self):
-        # TODO: Specifies the datasets.DatasetInfo object
         return datasets.DatasetInfo(
             description=_DESCRIPTION,
             features=datasets.Features(
-                {"translation": datasets.features.Translation(languages=(self.config.src, self.config.tgt))}
+                {"translation": datasets.features.Translation(languages=[self.config.src, self.config.tgt])}
             ),
             supervised_keys=(self.config.src, self.config.tgt),
-            homepage="http://preon.iiit.ac.in/~jerin/bhasha/",
+            homepage=_HOMEPAGE,
+            license=_LICENSE,
             citation=_CITATION,
         )
 
     def _split_generators(self, dl_manager):
-        dl_dir = dl_manager.download_and_extract(_URL)
-
-        data_dir = os.path.join(dl_dir, f"pib/{self.config.src}-{self.config.tgt}")
+        archive = dl_manager.download(_URL[str(self.config.version)])
         return [
             datasets.SplitGenerator(
                 name=datasets.Split.TRAIN,
-                # These kwargs will be passed to _generate_examples
                 gen_kwargs={
-                    "filepath": os.path.join(data_dir, f"train.{self.config.src}"),
-                    "labelpath": os.path.join(data_dir, f"train.{self.config.tgt}"),
+                    "archive": dl_manager.iter_archive(archive),
                 },
             ),
         ]
 
-    def _generate_examples(self, filepath, labelpath):
-        """Yields examples."""
-        with open(filepath, encoding="utf-8") as f1, open(labelpath, encoding="utf-8") as f2:
-            src = f1.read().split("\n")[:-1]
-            tgt = f2.read().split("\n")[:-1]
-            for idx, (s, t) in enumerate(zip(src, tgt)):
-                yield idx, {"translation": {self.config.src: s, self.config.tgt: t}}
+    def _generate_examples(self, archive):
+        root_dir = _ROOT_DIR[str(self.config.version)]
+        data_dir = f"{root_dir}/{self.config.src}-{self.config.tgt}"
+        src = tgt = None
+        for path, file in archive:
+            if data_dir in path:
+                if f"{data_dir}/train.{self.config.src}" in path:
+                    src = file.read().decode("utf-8").split("\n")[:-1]
+                if f"{data_dir}/train.{self.config.tgt}" in path:
+                    tgt = file.read().decode("utf-8").split("\n")[:-1]
+            if src and tgt:
+                break
+        for idx, (s, t) in enumerate(zip(src, tgt)):
+            yield idx, {"translation": {self.config.src: s, self.config.tgt: t}}
