@@ -16,14 +16,11 @@
 # Lint as: python3
 """The General Language Understanding Evaluation (Pragmeval) benchmark."""
 
-from __future__ import absolute_import, division, print_function
 
 import csv
 import os
 import textwrap
 
-import six
-
 import datasets
 
 
@@ -518,7 +515,7 @@ class Pragmeval(datasets.GeneratorBasedBuilder):
     ]
 
     def _info(self):
-        features = {text_feature: datasets.Value("string") for text_feature in six.iterkeys(self.config.text_features)}
+        features = {text_feature: datasets.Value("string") for text_feature in self.config.text_features.keys()}
         if self.config.label_classes:
             features["label"] = datasets.features.ClassLabel(names=self.config.label_classes)
         else:
@@ -569,7 +566,7 @@ class Pragmeval(datasets.GeneratorBasedBuilder):
 
             for n, row in enumerate(reader):
 
-                example = {feat: row[col] for feat, col in six.iteritems(self.config.text_features)}
+                example = {feat: row[col] for feat, col in self.config.text_features.items()}
                 example["idx"] = n
 
                 if self.config.label_column in row:
