@@ -20,6 +20,7 @@
 import os
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 _CITATION = """\
@@ -62,6 +63,7 @@ class SmsSpam(datasets.GeneratorBasedBuilder):
             supervised_keys=("sms", "label"),
             homepage="http://archive.ics.uci.edu/ml/datasets/SMS+Spam+Collection",
             citation=_CITATION,
+            task_templates=[TextClassification(text_column="sms", label_column="label")],
         )
 
     def _split_generators(self, dl_manager):
