@@ -20,6 +20,7 @@
 import json
 
 import datasets
+from datasets.tasks import TextClassification
 
 
 _DESCRIPTION = """\
@@ -91,6 +92,7 @@ class SnipsBuiltInIntents(datasets.GeneratorBasedBuilder):
             ),
             homepage="https://github.com/sonos/nlu-benchmark/tree/master/2016-12-built-in-intents",
             citation=_CITATION,
+            task_templates=[TextClassification(text_column="text", label_column="label")],
         )
 
     def _split_generators(self, dl_manager):
