@@ -41,7 +41,7 @@ from .arrow_reader import (
     ReadInstruction,
 )
 from .arrow_writer import ArrowWriter, BeamWriter
-from .data_files import DataFilesDict, _sanitize_patterns
+from .data_files import DataFilesDict, sanitize_patterns
 from .dataset_dict import DatasetDict, IterableDatasetDict
 from .fingerprint import Hasher
 from .info import DatasetInfo, DatasetInfosDict, PostProcessedInfo
@@ -203,6 +203,7 @@ class DatasetBuilder:
         name: Optional[str] = None,
         hash: Optional[str] = None,
         base_path: Optional[str] = None,
+        info: Optional[DatasetInfo] = None,
         features: Optional[Features] = None,
         use_auth_token: Optional[Union[bool, str]] = None,
         namespace: Optional[str] = None,
@@ -245,7 +246,7 @@ class DatasetBuilder:
 
         if data_files is not None and not isinstance(data_files, DataFilesDict):
             data_files = DataFilesDict.from_local_or_remote(
-                _sanitize_patterns(data_files), base_path=base_path, use_auth_token=use_auth_token
+                sanitize_patterns(data_files), base_path=base_path, use_auth_token=use_auth_token
             )
 
         # Prepare config: DatasetConfig contains name, version and description but can be extended by each dataset
@@ -263,11 +264,12 @@ class DatasetBuilder:
 
         # prepare info: DatasetInfo are a standardized dataclass across all datasets
         # Prefill datasetinfo
-        info = self.get_exported_dataset_info()
-        info.update(self._info())
-        info.builder_name = self.name
-        info.config_name = self.config.name
-        info.version = self.config.version
+        if info is None:
+            info = self.get_exported_dataset_info()
+            info.update(self._info())
+            info.builder_name = self.name
+            info.config_name = self.config.name
+            info.version = self.config.version
         self.info = info
         # update info with user specified infos
         if features is not None:
@@ -289,9 +291,7 @@ class DatasetBuilder:
                     self.info = DatasetInfo.from_directory(self._cache_dir)
                 else:  # dir exists but no data, remove the empty dir as data aren't available anymore
                     logger.warning(
-                        "Old caching folder {} for dataset {} exists but not data were found. Removing it. ".format(
-                            self._cache_dir, self.name
-                        )
+                        f"Old caching folder {self._cache_dir} for dataset {self.name} exists but not data were found. Removing it. "
                     )
                     os.rmdir(self._cache_dir)
 
@@ -331,25 +331,23 @@ class DatasetBuilder:
         if name is None and self.BUILDER_CONFIGS and not config_kwargs:
             if self.DEFAULT_CONFIG_NAME is not None:
                 builder_config = self.builder_configs.get(self.DEFAULT_CONFIG_NAME)
-                logger.warning("No config specified, defaulting to: %s/%s", self.name, builder_config.name)
+                logger.warning(f"No config specified, defaulting to: {self.name}/{builder_config.name}")
             else:
                 if len(self.BUILDER_CONFIGS) > 1:
-                    example_of_usage = "load_dataset('{}', '{}')".format(self.name, self.BUILDER_CONFIGS[0].name)
+                    example_of_usage = f"load_dataset('{self.name}', '{self.BUILDER_CONFIGS[0].name}')"
                     raise ValueError(
                         "Config name is missing."
-                        "\nPlease pick one among the available configs: %s" % list(self.builder_configs.keys())
-                        + "\nExample of usage:\n\t`{}`".format(example_of_usage)
+                        f"\nPlease pick one among the available configs: {list(self.builder_configs.keys())}"
+                        + f"\nExample of usage:\n\t`{example_of_usage}`"
                     )
                 builder_config = self.BUILDER_CONFIGS[0]
-                logger.info("No config specified, defaulting to first: %s/%s", self.name, builder_config.name)
+                logger.info(f"No config specified, defaulting to first: {self.name}/{builder_config.name}")
 
         # try get config by name
         if isinstance(name, str):
             builder_config = self.builder_configs.get(name)
             if builder_config is None and self.BUILDER_CONFIGS:
-                raise ValueError(
-                    "BuilderConfig %s not found. Available: %s" % (name, list(self.builder_configs.keys()))
-                )
+                raise ValueError(f"BuilderConfig {name} not found. Available: {list(self.builder_configs.keys())}")
 
         # if not using an existing config, then create a new config on the fly with config_kwargs
         if not builder_config:
@@ -369,7 +367,7 @@ class DatasetBuilder:
                     setattr(builder_config, key, value)
 
         if not builder_config.name:
-            raise ValueError("BuilderConfig must have a name, got %s" % builder_config.name)
+            raise ValueError(f"BuilderConfig must have a name, got {builder_config.name}")
 
         # compute the config id that is going to be used for caching
         config_id = builder_config.create_config_id(
@@ -378,18 +376,17 @@ class DatasetBuilder:
         )
         is_custom = config_id not in self.builder_configs
         if is_custom:
-            logger.warning("Using custom data configuration %s", config_id)
+            logger.warning(f"Using custom data configuration {config_id}")
         else:
             if builder_config != self.builder_configs[builder_config.name]:
                 raise ValueError(
                     "Cannot name a custom BuilderConfig the same as an available "
-                    "BuilderConfig. Change the name. Available BuilderConfigs: %s"
-                    % (list(self.builder_configs.keys()))
+                    f"BuilderConfig. Change the name. Available BuilderConfigs: {list(self.builder_configs.keys())}"
                 )
             if not builder_config.version:
-                raise ValueError("BuilderConfig %s must have a version" % builder_config.name)
+                raise ValueError(f"BuilderConfig {builder_config.name} must have a version")
             # if not builder_config.description:
-            #     raise ValueError("BuilderConfig %s must have a description" % builder_config.name)
+            #     raise ValueError(f"BuilderConfig {builder_config.name} must have a description"  )
 
         return builder_config, config_id
 
@@ -401,7 +398,7 @@ class DatasetBuilder:
         configs = {config.name: config for config in cls.BUILDER_CONFIGS}
         if len(configs) != len(cls.BUILDER_CONFIGS):
             names = [config.name for config in cls.BUILDER_CONFIGS]
-            raise ValueError("Names in BUILDER_CONFIGS must not be duplicated. Got %s" % names)
+            raise ValueError(f"Names in BUILDER_CONFIGS must not be duplicated. Got {names}")
         return configs
 
     @property
@@ -453,14 +450,9 @@ class DatasetBuilder:
             other_version = version_dirs[0][0]
             if other_version != self.config.version:
                 warn_msg = (
-                    "Found a different version {other_version} of dataset {name} in "
-                    "cache_dir {cache_dir}. Using currently defined version "
-                    "{cur_version}.".format(
-                        other_version=str(other_version),
-                        name=self.name,
-                        cache_dir=self._cache_dir_root,
-                        cur_version=str(self.config.version),
-                    )
+                    f"Found a different version {str(other_version)} of dataset {self.name} in "
+                    f"cache_dir {self._cache_dir_root}. Using currently defined version "
+                    f"{str(self.config.version)}."
                 )
                 logger.warning(warn_msg)
 
@@ -517,6 +509,7 @@ class DatasetBuilder:
                 download_config = DownloadConfig(
                     cache_dir=self._cache_downloaded_dir,
                     force_download=bool(download_mode == GenerateMode.FORCE_REDOWNLOAD),
+                    force_extract=bool(download_mode == GenerateMode.FORCE_REDOWNLOAD),
                     use_etag=False,
                     use_auth_token=use_auth_token,
                 )  # We don't use etag for data files to speed up the process
@@ -536,22 +529,17 @@ class DatasetBuilder:
         with FileLock(lock_path):
             data_exists = os.path.exists(self._cache_dir)
             if data_exists and download_mode == GenerateMode.REUSE_DATASET_IF_EXISTS:
-                logger.warning("Reusing dataset %s (%s)", self.name, self._cache_dir)
+                logger.warning(f"Reusing dataset {self.name} ({self._cache_dir})")
                 # We need to update the info in case some splits were added in the meantime
                 # for example when calling load_dataset from multiple workers.
                 self.info = self._load_info()
                 self.download_post_processing_resources(dl_manager)
                 return
-            logger.info("Generating dataset %s (%s)", self.name, self._cache_dir)
+            logger.info(f"Generating dataset {self.name} ({self._cache_dir})")
             if not is_remote_url(self._cache_dir_root):  # if cache dir is local, check for available space
                 if not utils.has_sufficient_disk_space(self.info.size_in_bytes or 0, directory=self._cache_dir_root):
                     raise IOError(
-                        "Not enough disk space. Needed: {} (download: {}, generated: {}, post-processed: {})".format(
-                            utils.size_str(self.info.size_in_bytes or 0),
-                            utils.size_str(self.info.download_size or 0),
-                            utils.size_str(self.info.dataset_size or 0),
-                            utils.size_str(self.info.post_processing_size or 0),
-                        )
+                        f"Not enough disk space. Needed: {utils.size_str(self.info.size_in_bytes or 0)} (download: {utils.size_str(self.info.download_size or 0)}, generated: {utils.size_str(self.info.dataset_size or 0)}, post-processed: {utils.size_str(self.info.post_processing_size or 0)})"
                     )
 
             @contextlib.contextmanager
@@ -597,7 +585,7 @@ class DatasetBuilder:
                     downloaded_from_gcs = False
                     if try_from_hf_gcs:
                         try:
-                            self._download_prepared_from_hf_gcs(dl_manager._download_config)
+                            self._download_prepared_from_hf_gcs(dl_manager.download_config)
                             downloaded_from_gcs = True
                         except (DatasetNotOnHfGcsError, MissingFilesOnHfGcsError):
                             logger.info("Dataset not on Hf google storage. Downloading and preparing it from source")
@@ -626,7 +614,8 @@ class DatasetBuilder:
         if self.manual_download_instructions is not None and dl_manager.manual_dir is None:
             raise ManualDownloadError(
                 textwrap.dedent(
-                    f"""The dataset {self.name} with config {self.config.name} requires manual data.
+                    f"""\
+                    The dataset {self.name} with config {self.config.name} requires manual data.
                     Please follow the manual download instructions:
                      {self.manual_download_instructions}
                     Manual data can be loaded with:
@@ -646,14 +635,12 @@ class DatasetBuilder:
         for split in self.info.splits:
             for resource_file_name in self._post_processing_resources(split).values():
                 if os.sep in resource_file_name:
-                    raise ValueError("Resources shouldn't be in a sub-directory: {}".format(resource_file_name))
+                    raise ValueError(f"Resources shouldn't be in a sub-directory: {resource_file_name}")
                 try:
                     resource_path = utils.cached_path(remote_cache_dir + "/" + resource_file_name)
                     shutil.move(resource_path, os.path.join(self._cache_dir, resource_file_name))
                 except ConnectionError:
-                    logger.info(
-                        "Couldn't download resourse file {} from Hf google storage.".format(resource_file_name)
-                    )
+                    logger.info(f"Couldn't download resourse file {resource_file_name} from Hf google storage.")
         logger.info("Dataset downloaded from Hf google storage.")
 
     def _download_and_prepare(self, dl_manager, verify_infos, **prepare_split_kwargs):
@@ -689,7 +676,7 @@ class DatasetBuilder:
                     "._split_generator()."
                 )
 
-            logger.info("Generating split %s", split_generator.split_info.name)
+            logger.info(f"Generating split {split_generator.split_info.name}")
             split_dict.add(split_generator.split_info)
 
             try:
@@ -716,16 +703,14 @@ class DatasetBuilder:
         for split in self.info.splits:
             for resource_name, resource_file_name in self._post_processing_resources(split).items():
                 if os.sep in resource_file_name:
-                    raise ValueError("Resources shouldn't be in a sub-directory: {}".format(resource_file_name))
+                    raise ValueError(f"Resources shouldn't be in a sub-directory: {resource_file_name}")
                 resource_path = os.path.join(self._cache_dir, resource_file_name)
                 if not os.path.exists(resource_path):
                     downloaded_resource_path = self._download_post_processing_resources(
                         split, resource_name, dl_manager
                     )
                     if downloaded_resource_path:
-                        logger.info(
-                            "Downloaded post-processing resource {} as {}".format(resource_name, resource_file_name)
-                        )
+                        logger.info(f"Downloaded post-processing resource {resource_name} as {resource_file_name}")
                         shutil.move(downloaded_resource_path, resource_path)
 
     def _load_info(self) -> DatasetInfo:
@@ -765,16 +750,13 @@ class DatasetBuilder:
         if not os.path.exists(self._cache_dir):
             raise AssertionError(
                 (
-                    "Dataset %s: could not find data in %s. Please make sure to call "
+                    f"Dataset {self.name}: could not find data in {self._cache_dir_root}. Please make sure to call "
                     "builder.download_and_prepare(), or pass download=True to "
                     "datasets.load_dataset() before trying to access the Dataset object."
                 )
-                % (self.name, self._cache_dir_root)
             )
 
-        logger.debug(
-            "Constructing Dataset for split %s, from %s", split or ", ".join(self.info.splits), self._cache_dir
-        )
+        logger.debug(f'Constructing Dataset for split {split or ", ".join(self.info.splits)}, from {self._cache_dir}')
 
         # By default, return all splits
         if split is None:
@@ -819,7 +801,7 @@ class DatasetBuilder:
         if run_post_process:
             for resource_file_name in self._post_processing_resources(split).values():
                 if os.sep in resource_file_name:
-                    raise ValueError("Resources shouldn't be in a sub-directory: {}".format(resource_file_name))
+                    raise ValueError(f"Resources shouldn't be in a sub-directory: {resource_file_name}")
             resources_paths = {
                 resource_name: os.path.join(self._cache_dir, resource_file_name)
                 for resource_name, resource_file_name in self._post_processing_resources(split).items()
@@ -858,9 +840,7 @@ class DatasetBuilder:
                 if self.info.post_processed.features is not None:
                     if self.info.post_processed.features.type != ds.features.type:
                         raise ValueError(
-                            "Post-processed features info don't match the dataset:\nGot\n{}\nbut expected something like\n{}".format(
-                                self.info.post_processed.features, ds.features
-                            )
+                            f"Post-processed features info don't match the dataset:\nGot\n{self.info.post_processed.features}\nbut expected something like\n{ds.features}"
                         )
                     else:
                         ds.info.features = self.info.post_processed.features
@@ -1080,7 +1060,7 @@ class GeneratorBasedBuilder(DatasetBuilder):
     def _prepare_split(self, split_generator):
         split_info = split_generator.split_info
 
-        fname = "{}-{}.arrow".format(self.name, split_generator.name)
+        fname = f"{self.name}-{split_generator.name}.arrow"
         fpath = os.path.join(self._cache_dir, fname)
 
         generator = self._generate_examples(**split_generator.gen_kwargs)
@@ -1148,7 +1128,7 @@ class ArrowBasedBuilder(DatasetBuilder):
         raise NotImplementedError()
 
     def _prepare_split(self, split_generator):
-        fname = "{}-{}.arrow".format(self.name, split_generator.name)
+        fname = f"{self.name}-{split_generator.name}.arrow"
         fpath = os.path.join(self._cache_dir, fname)
 
         generator = self._generate_tables(**split_generator.gen_kwargs)
@@ -1252,7 +1232,7 @@ class BeamBasedBuilder(DatasetBuilder):
                 "\nIf you really want to run it locally because you feel like the "
                 "Dataset is small enough, you can use the local beam runner called "
                 "`DirectRunner` (you may run out of memory). \nExample of usage: "
-                "\n\t`{}`".format(usage_example)
+                f"\n\t`{usage_example}`"
             )
 
         beam_options = beam_options or beam.options.pipeline_options.PipelineOptions()
@@ -1303,7 +1283,7 @@ class BeamBasedBuilder(DatasetBuilder):
         output_prefix = os.path.join(self._cache_dir, output_prefix)
 
         # To write examples to disk:
-        fname = "{}-{}.arrow".format(self.name, split_name)
+        fname = f"{self.name}-{split_name}.arrow"
         fpath = os.path.join(self._cache_dir, fname)
         beam_writer = BeamWriter(
             features=self.info.features, path=fpath, namespace=split_name, cache_dir=self._cache_dir
