@@ -116,13 +116,17 @@ if USE_BEAM in ENV_VARS_TRUE_AND_AUTO_VALUES:
     try:
         BEAM_VERSION = version.parse(importlib_metadata.version("apache_beam"))
         BEAM_AVAILABLE = True
-        logger.info("Apache Beam version {} available.".format(BEAM_VERSION))
+        logger.info(f"Apache Beam version {BEAM_VERSION} available.")
     except importlib_metadata.PackageNotFoundError:
         pass
 else:
     logger.info("Disabling Apache Beam because USE_BEAM is set to False")
 
 
+# Optional tools for feature decoding
+PIL_AVAILABLE = importlib.util.find_spec("PIL") is not None
+
+
 # Optional compression tools
 RARFILE_AVAILABLE = importlib.util.find_spec("rarfile") is not None
 ZSTANDARD_AVAILABLE = importlib.util.find_spec("zstandard") is not None
@@ -187,6 +191,10 @@ MODULE_NAME_FOR_DYNAMIC_MODULES = "datasets_modules"
 MAX_DATASET_CONFIG_ID_READABLE_LENGTH = 255
 
 # Streaming
-
 STREAMING_READ_MAX_RETRIES = 20
 STREAMING_READ_RETRY_INTERVAL = 5
+
+# Datasets without script
+DATA_FILES_MAX_NUMBER_FOR_MODULE_INFERENCE = 200
+GLOBBED_DATA_FILES_MAX_NUMBER_FOR_MODULE_INFERENCE = 10
+ARCHIVED_DATA_FILES_MAX_NUMBER_FOR_MODULE_INFERENCE = 200
