@@ -7,6 +7,7 @@ import tempfile
 import weakref
 from dataclasses import asdict
 from functools import wraps
+from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
 import numpy as np
@@ -82,7 +83,7 @@ def maybe_register_dataset_for_temp_dir_deletion(dataset):
     if _DATASETS_WITH_TABLE_IN_TEMP_DIR is None:
         _DATASETS_WITH_TABLE_IN_TEMP_DIR = weakref.WeakSet()
     if any(
-        os.path.samefile(os.path.dirname(cache_file["filename"]), _TEMP_DIR_FOR_TEMP_CACHE_FILES.name)
+        Path(_TEMP_DIR_FOR_TEMP_CACHE_FILES.name) in Path(cache_file["filename"]).parents
         for cache_file in dataset.cache_files
     ):
         _DATASETS_WITH_TABLE_IN_TEMP_DIR.add(dataset)
@@ -334,23 +335,27 @@ def fingerprint_transform(
             It should be in the format "MAJOR.MINOR.PATCH".
     """
 
-    assert use_kwargs is None or isinstance(use_kwargs, list), "use_kwargs is supposed to be a list, not {}".format(
-        type(use_kwargs)
-    )
-    assert ignore_kwargs is None or isinstance(
-        ignore_kwargs, list
-    ), "ignore_kwargs is supposed to be a list, not {}".format(type(use_kwargs))
-    assert not inplace or not fingerprint_names, "fingerprint_names are only used when inplace is False"
+    if use_kwargs is not None and not isinstance(use_kwargs, list):
+        raise ValueError(f"use_kwargs is supposed to be a list, not {type(use_kwargs)}")
+
+    if ignore_kwargs is not None and not isinstance(ignore_kwargs, list):
+        raise ValueError(f"ignore_kwargs is supposed to be a list, not {type(use_kwargs)}")
+
+    if inplace and fingerprint_names:
+        raise ValueError("fingerprint_names are only used when inplace is False")
+
     fingerprint_names = fingerprint_names if fingerprint_names is not None else ["new_fingerprint"]
 
     def _fingerprint(func):
 
-        assert inplace or all(  # check that not in-place functions require fingerprint parameters
-            name in func.__code__.co_varnames for name in fingerprint_names
-        ), "function {} is missing parameters {} in signature".format(func, fingerprint_names)
+        if not inplace and not all(name in func.__code__.co_varnames for name in fingerprint_names):
+            raise ValueError("function {func} is missing parameters {fingerprint_names} in signature")
+
         if randomized_function:  # randomized function have seed and generator parameters
-            assert "seed" in func.__code__.co_varnames, "'seed' must be in {}'s signature".format(func)
-            assert "generator" in func.__code__.co_varnames, "'generator' must be in {}'s signature".format(func)
+            if "seed" not in func.__code__.co_varnames:
+                raise ValueError(f"'seed' must be in {func}'s signature")
+            if "generator" not in func.__code__.co_varnames:
+                raise ValueError(f"'generator' must be in {func}'s signature")
         # this has to be outside the wrapper or since __qualname__ changes in multiprocessing
         transform = f"{func.__module__}.{func.__qualname__}"
         if version is not None:
