@@ -34,9 +34,7 @@ import dataclasses
 import json
 import os
 from dataclasses import asdict, dataclass, field
-from typing import List, Optional, Union
-
-from datasets.tasks.text_classification import TextClassification
+from typing import Dict, List, Optional, Union
 
 from . import config
 from .features import Features, Value
@@ -171,16 +169,13 @@ class DatasetInfo:
                 template = task_template_from_dict(self.task_templates)
                 self.task_templates = [template] if template is not None else []
 
-        # Insert labels and mappings for text classification
+        # Align task templates with features
         if self.task_templates is not None:
             self.task_templates = list(self.task_templates)
             if self.features is not None:
-                for idx, template in enumerate(self.task_templates):
-                    if isinstance(template, TextClassification):
-                        labels = self.features[template.label_column].names
-                        self.task_templates[idx] = TextClassification(
-                            text_column=template.text_column, label_column=template.label_column, labels=labels
-                        )
+                self.task_templates = [
+                    template.align_with_features(self.features) for template in (self.task_templates)
+                ]
 
     def _license_path(self, dataset_info_dir):
         return os.path.join(dataset_info_dir, config.LICENSE_FILENAME)
@@ -247,7 +242,7 @@ class DatasetInfo:
             dataset_info_dir (`str`): The directory containing the metadata file. This
                 should be the root directory of a specific dataset version.
         """
-        logger.info("Loading Dataset info from %s", dataset_info_dir)
+        logger.info(f"Loading Dataset info from {dataset_info_dir}")
         if not dataset_info_dir:
             raise ValueError("Calling DatasetInfo.from_directory() with undefined dataset_info_dir.")
 
@@ -274,22 +269,22 @@ class DatasetInfo:
         return self.__class__(**{k: copy.deepcopy(v) for k, v in self.__dict__.items()})
 
 
-class DatasetInfosDict(dict):
+class DatasetInfosDict(Dict[str, DatasetInfo]):
     def write_to_directory(self, dataset_infos_dir, overwrite=False):
         total_dataset_infos = {}
         dataset_infos_path = os.path.join(dataset_infos_dir, config.DATASETDICT_INFOS_FILENAME)
         if os.path.exists(dataset_infos_path) and not overwrite:
-            logger.info("Dataset Infos already exists in {}. Completing it with new infos.".format(dataset_infos_dir))
+            logger.info(f"Dataset Infos already exists in {dataset_infos_dir}. Completing it with new infos.")
             total_dataset_infos = self.from_directory(dataset_infos_dir)
         else:
-            logger.info("Writing new Dataset Infos in {}".format(dataset_infos_dir))
+            logger.info(f"Writing new Dataset Infos in {dataset_infos_dir}")
         total_dataset_infos.update(self)
         with open(dataset_infos_path, "w", encoding="utf-8") as f:
             json.dump({config_name: asdict(dset_info) for config_name, dset_info in total_dataset_infos.items()}, f)
 
     @classmethod
     def from_directory(cls, dataset_infos_dir):
-        logger.info("Loading Dataset Infos from {}".format(dataset_infos_dir))
+        logger.info(f"Loading Dataset Infos from {dataset_infos_dir}")
         with open(os.path.join(dataset_infos_dir, config.DATASETDICT_INFOS_FILENAME), "r", encoding="utf-8") as f:
             dataset_infos_dict = {
                 config_name: DatasetInfo.from_dict(dataset_info_dict)
@@ -354,7 +349,7 @@ class MetricInfo:
             metric_info_dir: `str` The directory containing the metadata file. This
                 should be the root directory of a specific dataset version.
         """
-        logger.info("Loading Metric info from %s", metric_info_dir)
+        logger.info(f"Loading Metric info from {metric_info_dir}")
         if not metric_info_dir:
             raise ValueError("Calling MetricInfo.from_directory() with undefined metric_info_dir.")
 
