@@ -8,6 +8,7 @@ from ..packaged_modules.json.json import Json
 from ..utils import logging
 from ..utils.typing import NestedDataStructureLike, PathLike
 from .abc import AbstractDatasetReader
+from .handler import IOHandler
 
 
 class JsonDatasetReader(AbstractDatasetReader):
@@ -67,7 +68,9 @@ class JsonDatasetWriter:
         num_proc: Optional[int] = None,
         **to_json_kwargs,
     ):
-        assert num_proc is None or num_proc > 0, "num_proc must be an integer > 0."
+        if num_proc is not None and num_proc <= 0:
+            raise ValueError(f"num_proc {num_proc} must be an integer > 0.")
+
         self.dataset = dataset
         self.path_or_buf = path_or_buf
         self.batch_size = batch_size if batch_size else config.DEFAULT_MAX_BATCH_SIZE
@@ -79,9 +82,13 @@ class JsonDatasetWriter:
         _ = self.to_json_kwargs.pop("path_or_buf", None)
         orient = self.to_json_kwargs.pop("orient", "records")
         lines = self.to_json_kwargs.pop("lines", True)
+        compression = self.to_json_kwargs.pop("compression", None)
+
+        if compression not in [None, "gzip"]:
+            raise NotImplementedError(f"Datasets currently does not support {compression} compression")
 
         if isinstance(self.path_or_buf, (str, bytes, os.PathLike)):
-            with open(self.path_or_buf, "wb+") as buffer:
+            with IOHandler(self.path_or_buf, "wb", compression) as buffer:
                 written = self._write(file_obj=buffer, orient=orient, lines=lines, **self.to_json_kwargs)
         else:
             written = self._write(file_obj=self.path_or_buf, orient=orient, lines=lines, **self.to_json_kwargs)
