@@ -8,6 +8,7 @@ import copy
 import io
 import json
 import os
+import posixpath
 import re
 import shutil
 import sys
@@ -21,10 +22,9 @@ from functools import partial
 from hashlib import sha256
 from pathlib import Path
 from typing import Dict, Optional, TypeVar, Union
-from urllib.parse import urlparse
+from urllib.parse import urljoin, urlparse
 
 import numpy as np
-import posixpath
 import requests
 
 from .. import __version__, config, utils
@@ -239,6 +239,8 @@ class DownloadConfig:
         max_retries (:obj:`int`, default ``1``): The number of times to retry an HTTP request if it fails.
         use_auth_token (:obj:`str` or :obj:`bool`, optional): Optional string or boolean to use as Bearer token
             for remote files on the Datasets Hub. If True, will get token from ~/.huggingface.
+        ignore_url_params (:obj:`bool`, default ``False``): Whether to strip all query parameters and #fragments from
+            the download URL before using it for caching the file.
     """
 
     cache_dir: Optional[Union[str, Path]] = None
@@ -254,6 +256,7 @@ class DownloadConfig:
     num_proc: Optional[int] = None
     max_retries: int = 1
     use_auth_token: Optional[Union[str, bool]] = None
+    ignore_url_params: bool = False
 
     def copy(self) -> "DownloadConfig":
         return self.__class__(**{k: copy.deepcopy(v) for k, v in self.__dict__.items()})
@@ -303,16 +306,17 @@ def cached_path(
             use_etag=download_config.use_etag,
             max_retries=download_config.max_retries,
             use_auth_token=download_config.use_auth_token,
+            ignore_url_params=download_config.ignore_url_params,
         )
     elif os.path.exists(url_or_filename):
         # File, and it exists.
         output_path = url_or_filename
     elif is_local_path(url_or_filename):
         # File, but it doesn't exist.
-        raise FileNotFoundError("Local file {} doesn't exist".format(url_or_filename))
+        raise FileNotFoundError(f"Local file {url_or_filename} doesn't exist")
     else:
         # Something unknown
-        raise ValueError("unable to parse {} as a URL or as a local path".format(url_or_filename))
+        raise ValueError(f"unable to parse {url_or_filename} as a URL or as a local path")
 
     if output_path is None:
         return output_path
@@ -326,18 +330,18 @@ def cached_path(
 
 
 def get_datasets_user_agent(user_agent: Optional[Union[str, dict]] = None) -> str:
-    ua = "datasets/{}; python/{}".format(__version__, config.PY_VERSION)
-    ua += "; pyarrow/{}".format(config.PYARROW_VERSION)
+    ua = f"datasets/{__version__}; python/{config.PY_VERSION}"
+    ua += f"; pyarrow/{config.PYARROW_VERSION}"
     if config.TORCH_AVAILABLE:
-        ua += "; torch/{}".format(config.TORCH_VERSION)
+        ua += f"; torch/{config.TORCH_VERSION}"
     if config.TF_AVAILABLE:
-        ua += "; tensorflow/{}".format(config.TF_VERSION)
+        ua += f"; tensorflow/{config.TF_VERSION}"
     if config.JAX_AVAILABLE:
-        ua += "; jax/{}".format(config.JAX_VERSION)
+        ua += f"; jax/{config.JAX_VERSION}"
     if config.BEAM_AVAILABLE:
-        ua += "; apache_beam/{}".format(config.BEAM_VERSION)
+        ua += f"; apache_beam/{config.BEAM_VERSION}"
     if isinstance(user_agent, dict):
-        ua += "; " + "; ".join("{}/{}".format(k, v) for k, v in user_agent.items())
+        ua += f"; {'; '.join(f'{k}/{v}' for k, v in user_agent.items())}"
     elif isinstance(user_agent, str):
         ua += "; " + user_agent
     return ua
@@ -355,7 +359,7 @@ def get_authentication_headers_for_url(url: str, use_auth_token: Optional[Union[
 
             token = hf_api.HfFolder.get_token()
         if token:
-            headers["authorization"] = "Bearer {}".format(token)
+            headers["authorization"] = f"Bearer {token}"
     return headers
 
 
@@ -434,7 +438,7 @@ def http_get(url, temp_file, proxies=None, resume_size=0, headers=None, cookies=
     headers = copy.deepcopy(headers) or {}
     headers["user-agent"] = get_datasets_user_agent(user_agent=headers.get("user-agent"))
     if resume_size > 0:
-        headers["Range"] = "bytes=%d-" % (resume_size,)
+        headers["Range"] = f"bytes={resume_size:d}-"
     response = _request_with_retry(
         method="GET",
         url=url,
@@ -495,13 +499,14 @@ def get_from_cache(
     cache_dir=None,
     force_download=False,
     proxies=None,
-    etag_timeout=10,
+    etag_timeout=100,
     resume_download=False,
     user_agent=None,
     local_files_only=False,
     use_etag=True,
     max_retries=0,
     use_auth_token=None,
+    ignore_url_params=False,
 ) -> str:
     """
     Given a URL, look for the corresponding file in the local cache.
@@ -523,15 +528,21 @@ def get_from_cache(
 
     os.makedirs(cache_dir, exist_ok=True)
 
-    original_url = url  # Some parameters may be added
+    if ignore_url_params:
+        # strip all query parameters and #fragments from the URL
+        cached_url = urljoin(url, urlparse(url).path)
+    else:
+        cached_url = url  # additional parameters may be added to the given URL
+
     connected = False
     response = None
     cookies = None
     etag = None
+    head_error = None
 
     # Try a first time to file the file on the local file system without eTag (None)
     # if we don't ask for 'force_download' then we spare a request
-    filename = hash_url_to_filename(original_url, etag=None)
+    filename = hash_url_to_filename(cached_url, etag=None)
     cache_path = os.path.join(cache_dir, filename)
 
     if os.path.exists(cache_path) and not force_download and not use_etag:
@@ -569,19 +580,28 @@ def get_from_cache(
                 or (response.status_code == 405 and "drive.google.com" in url)
                 or (
                     response.status_code == 403
-                    and re.match(r"^https?://github.com/.*?/.*?/releases/download/.*?/.*?$", url)
+                    and (
+                        re.match(r"^https?://github.com/.*?/.*?/releases/download/.*?/.*?$", url)
+                        or re.match(r"^https://.*?s3.*?amazonaws.com/.*?$", response.url)
+                    )
                 )
+                or (response.status_code == 403 and "ndownloader.figstatic.com" in url)
             ):
                 connected = True
-                logger.info("Couldn't get ETag version for url {}".format(url))
-        except (EnvironmentError, requests.exceptions.Timeout):
+                logger.info(f"Couldn't get ETag version for url {url}")
+            elif response.status_code == 401 and config.HF_ENDPOINT in url and use_auth_token is None:
+                raise ConnectionError(
+                    f"Unauthorized for URL {url}. Please use the parameter ``use_auth_token=True`` after logging in with ``huggingface-cli login``"
+                )
+        except (EnvironmentError, requests.exceptions.Timeout) as e:
             # not connected
+            head_error = e
             pass
 
     # connected == False = we don't have a connection, or url doesn't exist, or is otherwise inaccessible.
     # try to get the last downloaded one
     if not connected:
-        if os.path.exists(cache_path):
+        if os.path.exists(cache_path) and not force_download:
             return cache_path
         if local_files_only:
             raise FileNotFoundError(
@@ -589,12 +609,17 @@ def get_from_cache(
                 " disabled. To enable file online look-ups, set 'local_files_only' to False."
             )
         elif response is not None and response.status_code == 404:
-            raise FileNotFoundError("Couldn't find file at {}".format(url))
+            raise FileNotFoundError(f"Couldn't find file at {url}")
         _raise_if_offline_mode_is_enabled(f"Tried to reach {url}")
-        raise ConnectionError("Couldn't reach {}".format(url))
+        if head_error is not None:
+            raise ConnectionError(f"Couldn't reach {url} ({repr(head_error)})")
+        elif response is not None:
+            raise ConnectionError(f"Couldn't reach {url} (error {response.status_code})")
+        else:
+            raise ConnectionError(f"Couldn't reach {url}")
 
     # Try a second time
-    filename = hash_url_to_filename(original_url, etag)
+    filename = hash_url_to_filename(cached_url, etag)
     cache_path = os.path.join(cache_dir, filename)
 
     if os.path.exists(cache_path) and not force_download:
@@ -625,7 +650,7 @@ def get_from_cache(
         # Download to temporary file, then copy to cache dir once finished.
         # Otherwise you get corrupt cache entries if the download gets interrupted.
         with temp_file_manager() as temp_file:
-            logger.info("%s not found in cache or force_download set to True, downloading to %s", url, temp_file.name)
+            logger.info(f"{url} not found in cache or force_download set to True, downloading to {temp_file.name}")
 
             # GET file object
             if url.startswith("ftp://"):
@@ -641,10 +666,10 @@ def get_from_cache(
                     max_retries=max_retries,
                 )
 
-        logger.info("storing %s in cache at %s", url, cache_path)
+        logger.info(f"storing {url} in cache at {cache_path}")
         shutil.move(temp_file.name, cache_path)
 
-        logger.info("creating metadata file for %s", cache_path)
+        logger.info(f"creating metadata file for {cache_path}")
         meta = {"url": url, "etag": etag}
         meta_path = cache_path + ".json"
         with open(meta_path, "w", encoding="utf-8") as meta_file:
