@@ -23,13 +23,14 @@ import functools
 import itertools
 import os
 import pickle
+import re
 import sys
 import types
 from io import BytesIO as StringIO
 from multiprocessing import Pool, RLock
 from shutil import disk_usage
 from types import CodeType, FunctionType
-from typing import Callable, ClassVar, Generic, Optional, Tuple, Union
+from typing import Callable, ClassVar, Dict, Generic, Optional, Tuple, Union
 
 import dill
 import numpy as np
@@ -77,8 +78,35 @@ def size_str(size_in_bytes):
     for (name, size_bytes) in _NAME_LIST:
         value = size_in_bytes / size_bytes
         if value >= 1.0:
-            return "{:.2f} {}".format(value, name)
-    return "{} {}".format(int(size_in_bytes), "bytes")
+            return f"{value:.2f} {name}"
+    return f"{int(size_in_bytes)} bytes"
+
+
+def string_to_dict(string: str, pattern: str) -> Dict[str, str]:
+    """Un-format a string using a python f-string pattern.
+    From https://stackoverflow.com/a/36838374
+
+    Examples:
+
+        >>> p = 'hello, my name is {name} and I am a {age} year old {what}'
+        >>> s = p.format(name='cody', age=18, what='quarterback')
+        >>> s
+        'hello, my name is cody and I am a 18 year old quarterback'
+        >>> string_to_dict(s, p)
+        {'age': '18', 'name': 'cody', 'what': 'quarterback'}
+
+    Args:
+        string (str): input string
+        pattern (str): pattern formatted like a python f-string
+
+    Returns:
+        Dict[str, str]: dictionary of variable -> value, retrieved from the input using the pattern
+    """
+    regex = re.sub(r"{(.+?)}", r"(?P<_\1>.+)", pattern)
+    values = list(re.search(regex, string).groups())
+    keys = re.findall(r"{(.+?)}", pattern)
+    _dict = dict(zip(keys, values))
+    return _dict
 
 
 @contextlib.contextmanager
@@ -101,6 +129,23 @@ def unique_values(values):
             yield value
 
 
+def no_op_if_value_is_null(func):
+    """If the value is None, return None, else call `func`."""
+
+    def wrapper(value):
+        return func(value) if value is not None else None
+
+    return wrapper
+
+
+def first_non_null_value(iterable):
+    """Return the index and the value of the first non-null value in the iterable. If all values are None, return -1 as index."""
+    for i, value in enumerate(iterable):
+        if value is not None:
+            return i, value
+    return -1, None
+
+
 def zip_dict(*dicts):
     """Iterate over items of dictionaries grouped by their keys."""
     for key in unique_values(itertools.chain(*dicts)):  # set merge all keys
@@ -225,24 +270,25 @@ def map_nested(
             start = div * index + min(index, mod)
             end = start + div + (1 if index < mod else 0)
             split_kwds.append((function, iterable[start:end], types, index, disable_tqdm))
-        assert len(iterable) == sum(len(i[1]) for i in split_kwds), (
-            f"Error dividing inputs iterable among processes. "
-            f"Total number of objects {len(iterable)}, "
-            f"length: {sum(len(i[1]) for i in split_kwds)}"
-        )
-        logger.info(
-            "Spawning {} processes for {} objects in slices of {}".format(
-                num_proc, len(iterable), [len(i[1]) for i in split_kwds]
+
+        if len(iterable) != sum(len(i[1]) for i in split_kwds):
+            raise ValueError(
+                f"Error dividing inputs iterable among processes. "
+                f"Total number of objects {len(iterable)}, "
+                f"length: {sum(len(i[1]) for i in split_kwds)}"
             )
+
+        logger.info(
+            f"Spawning {num_proc} processes for {len(iterable)} objects in slices of {[len(i[1]) for i in split_kwds]}"
         )
         initargs, initializer = None, None
         if not disable_tqdm:
             initargs, initializer = (RLock(),), tqdm.set_lock
         with Pool(num_proc, initargs=initargs, initializer=initializer) as pool:
             mapped = pool.map(_single_map_nested, split_kwds)
-        logger.info("Finished {} processes".format(num_proc))
+        logger.info(f"Finished {num_proc} processes")
         mapped = [obj for proc_res in mapped for obj in proc_res]
-        logger.info("Unpacked {} objects".format(len(mapped)))
+        logger.info(f"Unpacked {len(mapped)} objects")
 
     if isinstance(data_struct, dict):
         return dict(zip(data_struct.keys(), mapped))
@@ -277,7 +323,7 @@ def flatten_nest_dict(d):
     flat_dict = NonMutableDict()
     for k, v in d.items():
         if isinstance(v, dict):
-            flat_dict.update({"{}/{}".format(k, k2): v2 for k2, v2 in flatten_nest_dict(v).items()})
+            flat_dict.update({f"{k}/{k2}": v2 for k2, v2 in flatten_nest_dict(v).items()})
         else:
             flat_dict[k] = v
     return flat_dict
@@ -405,7 +451,7 @@ class _CloudPickleTypeHintFix:
             else:
                 initargs = (obj.__origin__, (list(args[:-1]), args[-1]))
         else:  # pragma: no cover
-            raise pickle.PicklingError("Datasets pickle Error: Unknown type {}".format(type(obj)))
+            raise pickle.PicklingError(f"Datasets pickle Error: Unknown type {type(obj)}")
         pickler.save_reduce(_CloudPickleTypeHintFix._create_parametrized_type_hint, initargs, obj=obj)
 
 
@@ -416,7 +462,7 @@ def _save_code(pickler, obj):
     This is a modified version that removes the origin (filename + line no.)
     of functions created in notebooks or shells for example.
     """
-    dill._dill.log.info("Co: %s" % obj)
+    dill._dill.log.info(f"Co: {obj}")
     # The filename of a function is the .py file where it is defined.
     # Filenames of functions created in notebooks or shells start with '<'
     # ex: <ipython-input-13-9ed2afe61d25> for ipython, and <stdin> for shell
@@ -504,7 +550,7 @@ def save_function(pickler, obj):
     the keys in the output dictionary of globalvars can change.
     """
     if not dill._dill._locate_function(obj):
-        dill._dill.log.info("F1: %s" % obj)
+        dill._dill.log.info(f"F1: {obj}")
         if getattr(pickler, "_recurse", False):
             # recurse to get all globals referred to by obj
             globalvars = dill.detect.globalvars
@@ -563,7 +609,7 @@ def save_function(pickler, obj):
             pickler.clear_memo()
         dill._dill.log.info("# F1")
     else:
-        dill._dill.log.info("F2: %s" % obj)
+        dill._dill.log.info(f"F2: {obj}")
         name = getattr(obj, "__qualname__", getattr(obj, "__name__", None))
         dill._dill.StockPickler.save_global(pickler, obj, name=name)
         dill._dill.log.info("# F2")
@@ -581,7 +627,7 @@ try:
 
     @pklregister(type(regex.Regex("", 0)))
     def _save_regex(pickler, obj):
-        dill._dill.log.info("Re: %s" % obj)
+        dill._dill.log.info(f"Re: {obj}")
         args = (
             obj.pattern,
             obj.flags,
